# The cfgmdl package

## Set-up

From bash using pip
```
$ pip install cfgmdl
```

From source
```
git clone https://github.com/KIPAC/cfgmdl.git
cd cfgmdl
python setup.py install (or python setup.py develop)
```

## Testing

```
$ pip install pytest
$ pytest cfgmdl
```

## Demo

## People
* [Eric Charles](https://github.com/KIPAC/cfgmdl/issues/new?body=@eacharles) (KIPAC/SLAC)

## License, etc.

This is open source software, available under the BSD license. If you are interested in this project, please do drop us a line via the hyperlinked contact names above, or by [writing us an issue](https://github.com/KIPAC/cfgmdl/issues/new).
